==> nextcloud-21.0.8p0.tgz: nextcloud/apps/serverinfo/l10n/pt_BR.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informação da CPU não disponível",
    "Load average: {cpu} (last minute)" : "Média de carga: {cpu} (último minuto)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes} / Uso atual: {memUsageBytes}",
    "RAM info not available" : "Informação de RAM não disponível",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes} / Uso atual: {swapUsageBytes}",
    "SWAP info not available" : "Informação SWAP não disponível",
    "Users" : "Usuários",
    "Groups" : "Grupos",
    "Links" : "Links",
    "Emails" : "E-mails",
    "Federated sent" : "Envio federado",
    "Federated received" : "Recebimento federado",
    "Talk conversations" : "Conversas",
    "24 hours" : "24 horas",
    "1 hour" : "1 hora",
    "5 mins" : "5 mins",
    "Copy" : "Copiar",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressione Ctrl-C para copiar.",
    "System" : "Sistema",
    "Monitoring" : "Monitoramento",
    "Monitoring app with useful server information" : "Aplicativo de monitoramento com informações úteis do servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fornece informações úteis do servidor, como carga de CPU, uso de RAM, uso do disco, número de usuários, etc.",
    "Operating System" : "Sistema Operacional",
    "CPU" : "CPU",
    "Unknown Processor" : "Processador Desconhecido",
    "Memory" : "Memória",
    "Server time" : "Hora do servidor",
    "Uptime" : "Tempo ativo",
    "Load" : "Carga",
    "Disk" : "Disco",
    "Mount" : "Montagem",
    "Filesystem" : "Sistema de arquivos",
    "Size" : "Tamanho",
    "Available" : "Disponível",
    "Used" : "Usado",
    "You will get a notification once one of your disks is nearly full." : "Você receberá uma notificação quando um dos seus discos estiver quase cheio.",
    "Files" : "Arquivos",
    "Storages" : "Armazenamentos",
    "Free Space" : "Espaço livre",
    "Network" : "Rede",
    "Hostname" : "Hostname",
    "DNS" : "DNS",
    "Gateway" : "Gateway",
    "Status" : "Status",
    "Speed" : "Velocidade",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Usuários ativos",
    "Total users" : "Total de usuários",
    "Shares" : "Compartilhamentos",
    "PHP" : "PHP",
    "Version" : "Versão",
    "Memory limit" : "Limite de memória",
    "Max execution time" : "Tempo máximo de execução",
    "Upload max size" : "Tamanho máximo para envio",
    "Database" : "Banco de Dados",
    "Type" : "Tipo",
    "External monitoring tool" : "Ferramenta de monitoramento externo",
    "You can connect an external monitoring tool by using this end point" : "Você pode conectar uma ferramenta de monitoramento externa usando este ponto final",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Adicionar \"?format=json\" no final da URL dá a você o resultado em JSON.",
    "To use an access token, please generate one then set it using the following command" : "Para usar um token de acesso, gere um e defina-o usando o seguinte comando",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Em seguida, passe o token com o cabeçalho \"NC-Token\" ao consultar o URL acima.",
    "Load average" : "Carga média",
    "Last minute" : "Último minuto",
    "Memory info not available" : "Informações de memória não disponíveis",
    "Total" : "Total",
    "Current usage" : "Uso atual:",
    "Mails" : "E-mails",
    "Files:" : "Arquivos:",
    "Storages:" : "Armazenamentos:",
    "Free Space:" : "Espaço livre:",
    "Total users:" : "Total de usuários:",
    "Version:" : "Versão:",
    "Memory Limit:" : "Limite de memória:",
    "Max Execution Time:" : "Tempo máximo de execução:",
    "Upload max size:" : "Tamanho máximo para envio:",
    "Type:" : "Tipo:",
    "Size:" : "Tamanho:",
    "You can connect an external monitoring tool by using this end point:" : "Você pode conectar uma ferramenta de monitoramento externa usando este ponto final:",
    "To use an access token please generate one then set it using the following command:" : "Para usar um token de acesso, gere um e defina-o usando o seguinte comando:"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-22.1.1.tgz: nextcloud/apps/serverinfo/l10n/pt_BR.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informação da CPU não disponível",
    "Load average" : "Carga média",
    "Last minute" : "Último minuto",
    "Memory info not available" : "Informações de memória não disponíveis",
    "Total" : "Total",
    "Current usage" : "Uso atual:",
    "Users" : "Usuários",
    "Groups" : "Grupos",
    "Links" : "Links",
    "Mails" : "E-mails",
    "Federated sent" : "Envio federado",
    "Federated received" : "Recebimento federado",
    "Talk conversations" : "Conversas",
    "24 hours" : "24 horas",
    "1 hour" : "1 hora",
    "5 mins" : "5 mins",
    "Copy" : "Copiar",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressione Ctrl-C para copiar.",
    "System" : "Sistema",
    "Monitoring" : "Monitoramento",
    "Monitoring app with useful server information" : "Aplicativo de monitoramento com informações úteis do servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fornece informações úteis do servidor, como carga de CPU, uso de RAM, uso do disco, número de usuários, etc.",
    "Operating System" : "Sistema Operacional",
    "CPU" : "CPU",
    "Memory" : "Memória",
    "Server time" : "Hora do servidor",
    "Uptime" : "Tempo ativo",
    "Load" : "Carga",
    "Disk" : "Disco",
    "Mount" : "Montagem",
    "Filesystem" : "Sistema de arquivos",
    "Size" : "Tamanho",
    "Available" : "Disponível",
    "Used" : "Usado",
    "You will get a notification once one of your disks is nearly full." : "Você receberá uma notificação quando um dos seus discos estiver quase cheio.",
    "Files:" : "Arquivos:",
    "Storages:" : "Armazenamentos:",
    "Free Space:" : "Espaço livre:",
    "Network" : "Rede",
    "Hostname" : "Hostname",
    "DNS" : "DNS",
    "Gateway" : "Gateway",
    "Status" : "Status",
    "Speed" : "Velocidade",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Usuários ativos",
    "Total users:" : "Total de usuários:",
    "Shares" : "Compartilhamentos",
    "PHP" : "PHP",
    "Version:" : "Versão:",
    "Memory Limit:" : "Limite de memória:",
    "Max Execution Time:" : "Tempo máximo de execução:",
    "Upload max size:" : "Tamanho máximo para envio:",
    "Database" : "Banco de Dados",
    "Type:" : "Tipo:",
    "Size:" : "Tamanho:",
    "External monitoring tool" : "Ferramenta de monitoramento externo",
    "You can connect an external monitoring tool by using this end point:" : "Você pode conectar uma ferramenta de monitoramento externa usando este ponto final:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Adicionar \"?format=json\" no final da URL dá a você o resultado em JSON.",
    "To use an access token please generate one then set it using the following command:" : "Para usar um token de acesso, gere um e defina-o usando o seguinte comando:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Em seguida, passe o token com o cabeçalho \"NC-Token\" ao consultar o URL acima.",
    "Time Servers" : "Servidores de Horário"
},
"nplurals=2; plural=(n > 1);");
